%% fluorescence2Dplot.m :  Import and plotting of 2D data 
% by Evgenii Kovrigin, Marquette University
% ver. 3.0    6/25/2013-5/6/2014
%%
function fluorescence2Dplot(data, settings)


figure1 = figure;
axes1 = axes('Parent',figure1,'YGrid','on','XGrid','on','Layer','top',...
    'FontSize',14);
colormap(settings.colormap_name)
box(axes1,'on');
hold(axes1,'all');


% Generate custom contours
%%

%%
minZ=min(min(data.Z));
maxZ=max(max(data.Z));
DeltaZ=maxZ-minZ;
min_contour_level=minZ + DeltaZ*settings.lowest_contour_percent/100;
max_contour_level=minZ + DeltaZ*settings.highest_contour_percent/100;
delta_contour_level=(max_contour_level-min_contour_level)/settings.N_colors;
contour_range=min_contour_level:delta_contour_level:max_contour_level;
contourf(data.X,data.Y,data.Z, contour_range,'LineStyle','none')
% plot a line to separate upper and lower triangles
plot(data.X,data.X,'LineWidth',1,'Color',[0 0 0]);


%%
% Create xlabel
xlabel('Emission wavelength, nm','Interpreter','none','FontSize',16);

% Create ylabel
ylabel('Excitation wavelength, nm','FontSize',16);

% Create title
title({settings.dname},'Interpreter','none','FontSize',20);

% Put a notice that baseline correction was done
switch settings.baseline_correction
    case 'yes'
        bs_corr='bs_corr.';
    otherwise
        bs_corr='';
end
% Export
if strcmp(settings.graphics_export,'on')
    % incorporate contour values in the file name
    contour_string=sprintf('2D.min%d.max%d', settings.lowest_contour_percent, settings.highest_contour_percent);
    
    % Save MATLAB figure    
    saveas(figure1, fullfile(settings.dname, sprintf('%s.%s.%sfig',settings.dname,contour_string,bs_corr)));
    
    % Saving small PNG image
    if strcmp(settings.export_small_png,'yes')   print(figure1,'-dpng', sprintf('-r%d', settings.resolution_small_png), ...
            fullfile(settings.dname,sprintf('%s.%s.%ssmall.png',settings.dname,contour_string,bs_corr))); end
    
    % Saving large PNG image    
    if strcmp(settings.export_fine_png,'yes')  print(figure1,'-dpng', sprintf('-r%d', settings.resolution_fine_png), ...
        fullfile(settings.dname,sprintf('%s.%s.%slarge.png',settings.dname,contour_string,bs_corr))); end
    
    % Saving EPS file    
    if strcmp(settings.export_eps,'yes')  print(figure1,'-depsc2',fullfile(settings.dname, ...
            sprintf('%s.%s.%seps',settings.dname,contour_string,bs_corr))); end
    
end
